{ "name": "vitamin b", "measures": { "mass + mass equivalents": { "per package": { "grams": { "decimal string": "", "fraction string": "" }, "ounces": { } } }, # # # "mass": { "per package": { "grams": { "decimal string": "", "fraction string": "" }, "ounces": { } } }, # # "equivalents" # "mass equivalent": { "per package": { "grams": { "equivalent": "DFE", "decimal string": "", "fraction string": "" } } }, # # if IU # "biological activity": { "per package": { "IU": { "decimal string": "", "fraction string": "" } } } } }